// **********************************************************************
//
// Copyright (c) 1999
// Object-Oriented Concepts, Inc.
// Billerica, MA, USA
//
// Copyright (c) 1999
// Object-Oriented Concepts GmbH
// Ettlingen, Germany
//
// All Rights Reserved
//
// **********************************************************************

#ifndef OB_CODE_SET_UTIL_H
#define OB_CODE_SET_UTIL_H

namespace IOP
{

//
// Forward declarations
//
struct IOR;
struct TaggedComponent;

} // End of namespace IOP


namespace OB
{

class CodeSetUtil
{
    friend class CodeSetDatabase;

    //
    // The supported code sets in the preferred order
    //
    static ULongSeq supportedCodeSetsSeq_;

public:

    //
    // Create code set component info
    //
    static CONV_FRAME::CodeSetComponentInfo*
        createCodeSetComponentInfo(CORBA::ULong, CORBA::ULong);

    //
    // Create code set component for current code set settings
    //
    static CONV_FRAME::CodeSetComponent* createCodeSetComponent(CORBA::ULong);

    //
    // Create tagged component with code set information
    //
    static IOP::TaggedComponent*
        createTaggedComponentForCodeSets(CORBA::ULong, CORBA::ULong);

    //
    // Extract code set component info from IOR
    //
    static CONV_FRAME::CodeSetComponentInfo*
        getCodeSetComponentInfoFromIOR(const IOP::IOR*);

    //
    // Convert between UTF-8 and Unicode
    //
    static void unicodeToUtf8(CORBA::Octet*&, CORBA::WChar)
	throw(CORBA::DATA_CONVERSION);
    static CORBA::WChar utf8ToUnicode(CORBA::Octet*&)
	throw(CORBA::DATA_CONVERSION);

};

} // End of namespace OB

#endif
